@@ -27,6 +27,9 @@
 */
 /*******************************************************************************/
 #include "weather-event.h"
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
 gboolean not_event = FALSE;
 /*******************************************************************************/
@@ -37,9 +40,11 @@ gboolean timer_handler(gpointer data){
     struct	event_time *evt;
     time_t	current_time;
     int		check;
-#ifndef RELEASE
+#ifdef DEBUGEVENTS
     char   *temp_string;
-    fprintf(stderr, "Begin %s(): \n", __PRETTY_FUNCTION__);
+#endif
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
 #endif
     if(not_event == TRUE || !event_time_list)
 	return TRUE;
@@ -47,7 +52,7 @@ gboolean timer_handler(gpointer data){
     list_time_event_temp = event_time_list;  
     /* get current time */  
     current_time = time(NULL);
-#ifndef RELEASE
+#ifdef DEBUGEVENTS
     temp_string = ctime(&current_time);
     fprintf(stderr,"\nCurrent Time: %s\n",  temp_string);
 /*    g_free(temp_string);*/
@@ -57,13 +62,13 @@ gboolean timer_handler(gpointer data){
 	evt = list_time_event_temp->data;
 	if(evt->time <= current_time){
 	    switch(evt->type_event){
-		case DAYTIMEEVENT :
+		case CHANGE_DAY_PART :
 		#ifndef RELEASE
-		    fprintf(stderr,"DAYTIMEEVENT %s\n",ctime(&evt->time));
+		    fprintf(stderr,"CHANGE_DAY_PART %s\n",ctime(&evt->time));
 		#endif
 		    g_free(evt);
                     event_time_list = g_slist_remove(event_time_list, event_time_list->data);
-     		    weather_frame_update(FALSE);   
+     		    redraw_home_window(FALSE);   
 		break;
 		case DBUSINITEVENT:
 		#ifndef RELEASE
@@ -71,7 +76,7 @@ gboolean timer_handler(gpointer data){
 		#endif
 		    g_free(evt);
                     event_time_list = g_slist_remove(event_time_list, event_time_list->data);
-		    weather_initialize_dbus();
+/*		    weather_initialize_dbus();*/
 		    /* It is switch off the timer */	
 		    check = g_source_remove(app->timer);
 		    timer (60000);  /*Reintilize timer One per minute */
@@ -86,8 +91,7 @@ gboolean timer_handler(gpointer data){
 		#ifndef RELEASE
 		    fprintf(stderr,"UPDATE by event\n");
 		#endif
-		    app->show_update_window = FALSE;
-		    update_weather();
+		    update_weather(TRUE);
     		break;		    
 		case CHECK_GPS_POSITION:
 		    /* delete periodic update */
@@ -102,7 +106,7 @@ gboolean timer_handler(gpointer data){
 
 
 
-		#ifdef HILDON
+		#ifdef OS2008
 
 /* This is code for debug GPS
 
@@ -128,8 +132,8 @@ gboolean timer_handler(gpointer data){
                     if (calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
                                            app->temporary_station_latitude,app->temporary_station_longtitude)>10){
 								   
-                        get_nearest_station(app->temporary_station_latitude,app->temporary_station_longtitude
-            		                    ,&app->gps_station);		    
+                        get_nearest_station(app->temporary_station_latitude,app->temporary_station_longtitude,
+            		                    &app->gps_station);		    
 			if ((strlen(app->gps_station.id0) > 0) && (strlen(app->gps_station.name) > 0)){
 		    
 			    app->gps_station.latitude = app->temporary_station_latitude;
@@ -140,14 +144,13 @@ gboolean timer_handler(gpointer data){
 				app->config->current_station_name = g_strdup(app->gps_station.name);
 				app->config->current_station_id = g_strdup(app->gps_station.id0);		
 			    }
-			    new_config_save(app->config);
-                    	    app->show_update_window = FALSE;
-		    	    update_weather();
-			    weather_frame_update(FALSE);
+			    config_save(app->config);
+		    	    update_weather(TRUE);
+			    redraw_home_window(FALSE);
 			}        
                     }
 		#endif
-		#ifdef HILDON
+		#ifdef OS2008
                     /* add periodic gps check */
                     if (app->gps_station.latitude == 0 && app->gps_station.longtitude == 0)
                         add_gps_event(1);
@@ -167,8 +170,7 @@ gboolean timer_handler(gpointer data){
 		#ifndef RELEASE
 		    fprintf(stderr,"UPDATE by event\n");
 		#endif
-		    app->show_update_window = FALSE;
-		    update_weather();
+		    update_weather(FALSE);
                     /* add periodic update */
                     add_periodic_event(current_time);
     		break;		    
@@ -186,7 +188,9 @@ void print_list(char *buff, size_t buff_size){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     char	tmp[3072];
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     memset(tmp, 0, sizeof(tmp));
     if(!event_time_list)
 	return;
@@ -208,12 +212,18 @@ void print_list(char *buff, size_t buff_size){
 #endif
 /*******************************************************************************/
 void create_timer_with_interval(guint interval){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     app->timer = g_timeout_add(interval,
 			       (GtkFunction)timer_handler,
 			       NULL); /* One per minute */
 }
 /*******************************************************************************/
 void timer(int interval){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     app->timer = g_timeout_add(interval,
 			       (GtkFunction)timer_handler,
 			       app->main_window);
@@ -223,11 +233,13 @@ void timer(int interval){
 void free_list_time_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
-    
-    #ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Free ALL in list\n");
     print_list(NULL, 0);
-    #endif
+#endif
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list; 
@@ -242,30 +254,33 @@ void free_list_time_event(void){
     }
     g_slist_free(event_time_list);
     event_time_list = NULL;
-    #ifndef RELEASE
+#ifdef DEBUGEVENTS
     fprintf(stderr,"list clean\n");
     print_list(NULL, 0);
-    #endif
-
+#endif
 }
 /*******************************************************************************/
 /* Compare function for sort event list */
 static gint compare_time(gconstpointer a, gconstpointer b){
     struct event_time *evta, *evtb;
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
     evta = (struct event_time*)a;
     evtb = (struct event_time*)b;
     return(evta->time < evtb->time) ? -1 : (evta->time > evtb->time) ? +1 : 0;
 }
 /*******************************************************************************/
 /* Add time event  to list */	  
-void time_event_add(time_t time_value, short type_event){
+void event_add(time_t time_value, short type_event){
     struct event_time *evt = NULL;
-
-    #ifndef RELEASE
-    fprintf(stderr,"time_event_add in list\n");
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+#ifdef DEBUGEVENTS
+    fprintf(stderr, "event_add in list\n");
     print_list(NULL, 0); 
-    #endif
+#endif
     if( time_value && time_value > time(NULL)){ 
 	evt = g_new0(struct event_time, 1);
 	if (evt != NULL){
@@ -276,81 +291,76 @@ void time_event_add(time_t time_value, short type_event){
 	else
 	    fprintf(stderr,"evt NULL\n");
     }
-    #ifndef RELEASE
-    fprintf(stderr,"time_event_add in list finished\n");
+#ifdef DEBUGEVENTS
+    fprintf(stderr, "event_add in list finished\n");
     print_list(NULL, 0);
-    #endif
+#endif
 }
 /*******************************************************************************/
 /*  Addition the periodic time in the list of events  for weather forecast updating.  
     Interval is a count of minutes for the next interval */	  
 void add_gps_event(guint interval){
-
-    #ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Add in list\n");
     print_list(NULL, 0);
-    #endif
-
-
-	time_event_add(time(NULL) + interval *60, CHECK_GPS_POSITION); /* Every 'interval' minutes */ 
-
-    #ifndef RELEASE
+#endif
+    event_add(time(NULL) + interval *60, CHECK_GPS_POSITION); /* Every 'interval' minutes */ 
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Item added to list\n");
     print_list(NULL, 0);
-    #endif
-	
+#endif
 }
 /*******************************************************************************/
 /*  Addition the periodic time in the list of events  for GPS checking */	  
 void add_periodic_event(time_t last_update){
-
-    #ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Add in list\n");
     print_list(NULL, 0);
-    #endif
-
-/*    if(app->config->gps_station) */
-	time_event_add(last_update + app->config->update_interval * 60, AUTOUPDATE);
-
-    #ifndef RELEASE
+#endif
+    event_add(last_update + app->config->update_interval * 60, AUTOUPDATE);
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Item added to list\n");
     print_list(NULL, 0);
-    #endif
-	
+#endif
 }
 /*******************************************************************************/
 /* Addition the current time in the list of events  for weather forecast updating */	  
 void add_current_time_event(void){
-
     time_t current_time;	
-    
-    #ifndef RELEASE
-	fprintf(stderr,"Add in list\n");
-        print_list(NULL, 0);
-    #endif
-    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
+#ifdef DEBUGEVENTS
+    fprintf(stderr,"Add in list\n");
+    print_list(NULL, 0);
+#endif
     /* get current time */  
     current_time = time(NULL);
-    time_event_add(current_time + 4 , UPDATE_AFTER_CONNECTED); /* The current time plus 4 seconds */
+    event_add(current_time + 4 , UPDATE_AFTER_CONNECTED); /* The current time plus 4 seconds */
     
-    #ifndef RELEASE
-	fprintf(stderr,"Item added to list\n");
-	print_list(NULL, 0);
-    #endif
-	
+#ifdef DEBUGEVENTS
+    fprintf(stderr,"Item added to list\n");
+    print_list(NULL, 0);
+#endif
 }
-
 /*******************************************************************************/
 /* Remove periodic time event  from list */	  
 void remove_periodic_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
-    
-    #ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Periodic remove from list\n");
     print_list(NULL, 0);
-    #endif
-
+#endif
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list;  
@@ -364,27 +374,28 @@ void remove_periodic_event(void){
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 
-    #ifndef RELEASE
+#ifdef DEBUGEVENTS
     fprintf(stderr,"Periodic is remove from list\n");
     print_list(NULL, 0);
-    #endif
+#endif
 }
 /*******************************************************************************/
 void remove_daytime_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
-    
-    #ifndef RELEASE
-    fprintf(stderr,"DAYTIMEEVENT remove from list\n");
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
+#ifdef DEBUGEVENTS
+    fprintf(stderr,"CHANGE_DAY_PART remove from list\n");
     print_list(NULL, 0);
-    #endif
-
+#endif
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list;  
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
-	if(evt->type_event == DAYTIMEEVENT){
+	if(evt->type_event == CHANGE_DAY_PART){
 	    event_time_list = g_slist_remove(event_time_list, list_time_event_temp->data);
 	    list_time_event_temp = event_time_list;  
 	    g_free(evt);
@@ -392,16 +403,18 @@ void remove_daytime_event(void){
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 
-    #ifndef RELEASE
-    fprintf(stderr,"DAYTIMEEVENT is remove from list\n");
+#ifdef DEBUGEVENTS
+    fprintf(stderr,"CHANGE_DAY_PART is remove from list\n");
     print_list(NULL, 0);
-    #endif
+#endif
 }
 /*******************************************************************************/
 time_t next_update(void){
     GSList	*tmp_list = NULL;
     time_t	result	= 0;
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(!event_time_list)
 	return result;
     tmp_list = event_time_list;
