@@ -147,7 +147,7 @@ gboolean change_station_prev(GtkWidget *widget, GdkEvent *event,
 /* show popup window if received param */
     if(user_data){
 	day_number = (gint)g_object_get_data(G_OBJECT(user_data), "active_tab");
-	gtk_widget_destroy(user_data);
+	destroy_popup_window();
 	weather_window_popup(NULL, NULL, (gpointer)day_number);
     }
     return FALSE;
@@ -212,7 +212,7 @@ gboolean change_station_next(GtkWidget *widget, GdkEvent *event,
 /* show popup window if received param */
     if(user_data){
 	day_number = (gint)g_object_get_data(G_OBJECT(user_data), "active_tab");
-	gtk_widget_destroy(user_data);
+	destroy_popup_window();
         weather_window_popup(NULL, NULL, (gpointer)day_number);
     }
     return FALSE;
@@ -433,7 +433,7 @@ void draw_home_window(gint count_day){
         	event_add(day_begin_time - diff_time, CHANGE_DAY_PART);
 	    if(current_time < night_begin_time)
             	event_add(night_begin_time - diff_time, CHANGE_DAY_PART);
-	    
+/*	    
 	    #ifndef RELEASE
 		fprintf(stderr, "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 		fprintf(stderr, "\nUTC time %s", ctime(&utc_time));
@@ -444,7 +444,7 @@ void draw_home_window(gint count_day){
 		fprintf(stderr, "Current time: %s", ctime(&current_time));
  		fprintf(stderr, "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n");
 	    #endif
-
+*/
 	    if(i == 0){	/* first day */
 		update_time = last_update_time(app->wsd.current);
 		/* check weather data for actuality */
@@ -622,11 +622,11 @@ void update_weather(gboolean show_update_window){
     START_FUNCTION;
 #endif
     if(show_update_window)
-	app->show_update_window = TRUE;
+        app->show_update_window = TRUE;
     else
         app->show_update_window = FALSE;
     if(!app->flag_updating)
-	app->flag_updating = g_timeout_add(100, (GSourceFunc)download_html, NULL);
+        app->flag_updating = g_timeout_add(100, (GSourceFunc)download_html, NULL);
 }
 #ifndef OS2008
 /*******************************************************************************/
@@ -1548,6 +1548,7 @@ void delete_weather_day_button(WDB **day){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+    return;
     if(*day){
 	if((*day)->icon_image && GTK_IS_WIDGET((*day)->icon_image)){
 	    gtk_widget_destroy( (*day)->icon_image );
@@ -1593,7 +1594,7 @@ GtkListStore* create_user_stations_list(void){
 /*******************************************************************************/
 void add_change_day_part_event(GSList *day, guint year, guint month){
     gchar	buffer[255];
-    struct tm	tm;
+    struct tm	tm = {0};
     time_t	time;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -1614,7 +1615,7 @@ void add_change_day_part_event(GSList *day, guint year, guint month){
 /*******************************************************************************/
 time_t get_day_part_begin_time(GSList *day, guint year, const gchar *day_part){
     gchar	buffer[255];
-    struct tm	tm;
+    struct tm	tm = {0};
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -1813,6 +1814,7 @@ omweather_init(OMWeather *applet){
         return;
     }
     app->popup_window = NULL;
+    app->tab_of_window_popup = NULL;
     app->time_update_list = create_time_update_list();
     app->show_update_window = FALSE;
     /* Read Coutries list from file */
