@@ -44,6 +44,30 @@
 
 */
 /*******************************************************************************/
+void
+destroy_popup_window(void){
+    GSList	*tmp = NULL;
+    /* free Idles */
+    tmp = app->tab_of_window_popup;
+    while(tmp){
+#ifndef RELEASE    
+	    if 	(g_idle_remove_by_data(tmp->data))
+#else
+	g_idle_remove_by_data(tmp->data);
+#endif
+#ifndef RELEASE    		
+		    fprintf(stderr,"Succes\n");
+	    else
+	        fprintf(stderr,"Not Succes\n");
+#endif	    		
+	    tmp = g_slist_next(tmp);
+    }
+    g_slist_free(app->tab_of_window_popup);
+    app->tab_of_window_popup = NULL;
+    gtk_widget_destroy(GTK_WIDGET(app->popup_window));
+    app->popup_window = NULL;
+}
+/*******************************************************************************/
 GtkWidget* create_sun_time_widget(GSList *day){
     GtkWidget	*main_widget = NULL,
 		*main_label;
@@ -193,9 +217,14 @@ GtkWidget* create_time_updates_widget(GSList *current){
 /*******************************************************************************/
 gboolean make_current_tab(GtkWidget *vbox)
 {
+    if (app->popup_window){
 	GtkWidget *child = create_current_tab(app->wsd.current);
-	gtk_container_add(GTK_CONTAINER(vbox),child);
-	gtk_widget_show_all(vbox);
+	if (app->popup_window){
+	    gtk_container_add(GTK_CONTAINER(vbox),child);	
+	    gtk_widget_show_all(vbox);
+	}else
+	     gtk_widget_destroy(GTK_WIDGET(child));
+    }	
 	return FALSE;
 }
 /*******************************************************************************/
@@ -204,17 +233,21 @@ gboolean make_tab(GtkWidget *vbox)
         GSList	*day = NULL;
         gchar	*day_name = NULL;
 	GtkWidget *child;
-	day = (GSList*)g_object_get_data(G_OBJECT(vbox), "day");
-	child = create_day_tab(app->wsd.current, day, &day_name);
-	gtk_container_add(GTK_CONTAINER(vbox),child);
-	gtk_widget_show_all(vbox);
+	if (app->popup_window){
+	    day = (GSList*)g_object_get_data(G_OBJECT(vbox), "day");
+	    child = create_day_tab(app->wsd.current, day, &day_name);
+	    if (app->popup_window){
+		gtk_container_add(GTK_CONTAINER(vbox),child);
+		gtk_widget_show_all(vbox);
+	    }else
+	        gtk_widget_destroy(GTK_WIDGET(child));
+	}    
 	return FALSE;
 }
 /*******************************************************************************/
 gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
                     	    				    gpointer user_data){
-    GtkWidget	*window_popup = NULL,
-		*notebook = NULL,
+    GtkWidget	*notebook = NULL,
 		*tab = NULL,
 		*current_tab = NULL,
 		*label = NULL,
@@ -234,10 +267,11 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
                 current_data_last_update = 0;
     GSList	*tmp = NULL,
 		*day = NULL;
-    GtkStyle	*style = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+    if (app->popup_window || app->flag_updating != 0)
+       return FALSE;
 /* day number */
     active_tab = (gint)user_data;
 /* if no one station present in list show settings window */
@@ -246,39 +280,19 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 	return FALSE;
     }
 /* Main window */
-    window_popup = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    
-    if(app->config->ui_background_color_on)
-	set_background_color(window_popup, &(app->config->ui_background_color));
+    app->popup_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-    g_object_set_data(G_OBJECT(window_popup), "active_tab", (gpointer)active_tab);
-    gtk_window_fullscreen(GTK_WINDOW(window_popup));
+    g_object_set_data(G_OBJECT(app->popup_window), "active_tab", (gpointer)active_tab);
+    gtk_window_fullscreen(GTK_WINDOW(app->popup_window));
     /* create frame vbox */    
     vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_add(GTK_CONTAINER(window_popup), vbox);
+    gtk_container_add(GTK_CONTAINER(app->popup_window), vbox);
 /* station name */
     gtk_box_pack_start(GTK_BOX(vbox),
-			create_window_header(app->config->current_station_name, window_popup),
+			create_window_header(app->config->current_station_name, app->popup_window),
 			FALSE, TRUE, 20);
 /* create tabs widget */
     notebook = gtk_notebook_new();
-    if (app->config->ui_background_color_on){
-	set_background_color(notebook, &(app->config->ui_background_color));
-	style = gtk_widget_get_style(notebook);
-	/*
-	fprintf(stderr,"test %s %i\n",gtk_widget_get_composite_name(notebook),style->bg[GTK_STATE_ACTIVE].green);
-	fprintf(stderr,"test %s %i\n",gtk_widget_get_composite_name(notebook),style->bg[GTK_STATE_ACTIVE].red);
-	fprintf(stderr,"test %s %i\n",gtk_widget_get_composite_name(notebook),style->bg[GTK_STATE_ACTIVE].blue);
-    
-	style->fg[GTK_STATE_NORMAL].green = 10000;
-	style->fg[GTK_STATE_NORMAL].red = 60000;
-	style->fg[GTK_STATE_NORMAL].blue = 00000;    
-	style->fg[GTK_STATE_ACTIVE].green = 10000;
-	style->fg[GTK_STATE_ACTIVE].red = 60000;
-	style->fg[GTK_STATE_ACTIVE].blue = 40000;    
-	*/
-	gtk_widget_set_style(notebook,style);    
-    }	
     gtk_notebook_set_show_border(GTK_NOTEBOOK(notebook), FALSE);
 /* Current weather */
     current_time = time(NULL); /* get current day */
@@ -298,24 +312,35 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 	current_tab = gtk_vbox_new(FALSE, 0);
 
     if(current_tab){
-      if(active_tab == 0 && app->config->separate){
-        gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+	if(active_tab == 0 && app->config->separate)
+        {
+    	    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
 				current_tab,
 				gtk_label_new(_("Now")));
 	    make_current_tab(current_tab); 
-	  }else{
+        }else{
 	    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
 				current_tab,
 				gtk_label_new(_("Now")));
 	    g_idle_add((GSourceFunc)make_current_tab,current_tab);
-	  }
+	    add_item2object(&(app->tab_of_window_popup), (void*)current_tab);
+	}
     }
 /* if weather is separated than hide one day */
-    (app->config->separate) ? (k = 1) : (k = 0);
+    (app->config->separate) ? (k = 0) : (k = 1);
+    if(current_tab && !app->config->separate && active_tab != 0 ){
+       active_tab = active_tab + k;
+    }   
+
+    if (!app->config->separate && !current_tab ){
+	active_tab ++;
+    }	
+
 /* Day tabs */
     tmp = app->wsd.days;
-    while(tmp && i < app->config->days_to_show){
+    while(tmp && i < app->config->days_to_show + k){
 	day = (GSList*)tmp->data;
+
 	/* Acceleration of starting gtk_notebook */
 	if (active_tab != i){
 	    /* Create the empty page */
@@ -326,15 +351,16 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
         				gtk_label_new(day_name));
 		g_object_set_data(G_OBJECT(tab), "day", (gpointer)tmp->data);
 		g_idle_add((GSourceFunc)make_tab,tab);
+		add_item2object(&(app->tab_of_window_popup), (void*)tab);
 	    }
-	}else{	
-	    /* Create the page with data */
-	    tab = create_day_tab(app->wsd.current, day, &day_name);
-	    if(tab){
-		page = gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+	}else{
+		/* Create the page with data */
+		tab = create_day_tab(app->wsd.current, day, &day_name);
+		if(tab){
+		    page = gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         				tab,
         				gtk_label_new(day_name));
-	    }
+		}
 	}
 	day_name && (g_free(day_name), day_name = NULL);
 	tmp = g_slist_next(tmp);
@@ -353,12 +379,12 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
     settings_button = create_button_with_image(BUTTON_ICONS, "settings", 40, FALSE, FALSE);
     g_signal_connect(G_OBJECT(settings_button), "button_press_event",
                         G_CALLBACK(settings_button_handler),
-			(gpointer)window_popup);
+			(gpointer)app->popup_window);
     /* Refresh buton */
     refresh_button = create_button_with_image(BUTTON_ICONS, "refresh", 40, FALSE, FALSE);
     g_signal_connect(G_OBJECT(refresh_button), "button_press_event",
                         G_CALLBACK(refresh_button_handler),
-			(gpointer)window_popup);
+			(gpointer)app->popup_window);
     /* About buton */
     about_button = create_button_with_image(BUTTON_ICONS, "about", 40, FALSE, FALSE);
     g_signal_connect(G_OBJECT(about_button), "button_press_event",
@@ -368,15 +394,8 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
     close_button = create_button_with_image(BUTTON_ICONS, "close", 40, FALSE, FALSE);
     g_signal_connect(G_OBJECT(close_button), "button_press_event",
                         G_CALLBACK(popup_close_button_handler),
-			(gpointer)window_popup);
+			(gpointer)app->popup_window);
 
-/* Change background color on buttons */
-    if(app->config->ui_background_color_on){
-	set_background_color(close_button, &(app->config->ui_background_color));
-	set_background_color(settings_button, &(app->config->ui_background_color));
-	set_background_color(refresh_button, &(app->config->ui_background_color));	
-	set_background_color(about_button, &(app->config->ui_background_color));	
-    }			
 /* Pack buttons to the buttons box */
     gtk_box_pack_start(GTK_BOX(buttons_box), settings_button, FALSE, FALSE, 60);
     gtk_box_pack_start(GTK_BOX(buttons_box), refresh_button, TRUE, TRUE, 5);
@@ -389,7 +408,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
     	    hildon_banner_show_information(app->main_window,
 					    NULL,
 					    _("No weather data for this day."));
-	    gtk_widget_destroy(window_popup);
+	    destroy_popup_window();
 	    return FALSE;
 	}
 	else{
@@ -401,16 +420,11 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 			hildon_banner_show_information(app->main_window,
 							NULL,
 							_("No current weather data."));
-		        gtk_widget_destroy(window_popup);
+			destroy_popup_window();
 			return FALSE;
 		    }
 		}
 	    }
-	    else
-		if(current_tab && active_tab)
-		    active_tab++;
-		    
-	    gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), active_tab);
 	}
     }
     else{
@@ -426,7 +440,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 				FALSE, FALSE, 0);
 /* Pack buttons to the vbox */
     gtk_box_pack_start(GTK_BOX(vbox), buttons_box, FALSE, FALSE, 0);
-    gtk_widget_show_all(window_popup);
+    gtk_widget_show_all(app->popup_window);
     return FALSE;
 }
 /*******************************************************************************/
@@ -458,7 +472,7 @@ void settings_button_handler(GtkWidget *button, GdkEventButton *event,
 #endif
 /* For debug speed of creating setting window */
 /* time_start();  */
-    gtk_widget_destroy(GTK_WIDGET(user_data));
+    destroy_popup_window();
     weather_window_settings(NULL, NULL, (gpointer)day_number);
 /* fprintf(stderr,"Time: %lf msec Pi = %lf\n",time_stop(),weather_window_settings);*/
 }
@@ -468,7 +482,7 @@ void refresh_button_handler(GtkWidget *button, GdkEventButton *event,
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    gtk_widget_destroy(GTK_WIDGET(user_data));
+    destroy_popup_window();
     update_weather(TRUE);
 }
 /*******************************************************************************/
@@ -482,7 +496,7 @@ void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    gtk_widget_destroy(GTK_WIDGET(user_data));
+    destroy_popup_window();
 }
 /*******************************************************************************/
 GtkWidget* create_pseudo_day_tab(GSList *current, GSList *day, gchar **day_name){
@@ -739,6 +753,9 @@ GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
 			    create_time_updates_widget(current),
 			    TRUE, FALSE, 5);
     gtk_widget_show_all(main_widget);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
     return main_widget;
 }
 /*******************************************************************************/
@@ -819,9 +836,11 @@ GtkWidget* create_current_tab(GSList *current){
 	    default:
 	    case MB: units = _("mb"); break;
 	    case INCH: units = _("inHg"); tmp_pressure = mb2inch(tmp_pressure); break;
+	    case MM: units = _("mmHg"); tmp_pressure = mb2mm(tmp_pressure); break;
 	}
 
 	sprintf(buffer + strlen(buffer), "  %.2f %s,", tmp_pressure, units);
+
 	sprintf(buffer + strlen(buffer), "  %s\n",
 		    item_value(current, "pressure_direction"));
     }
@@ -932,10 +951,5 @@ GtkWidget* create_window_header(const gchar *station_name, GtkWidget *popup_wind
                 	G_CALLBACK(change_station_next), popup_window);
     }
 
-    if(app->config->ui_background_color_on){
-	set_background_color(previos_button, &(app->config->ui_background_color));
-	set_background_color(next_button, &(app->config->ui_background_color));
-    }
     return main_widget;
 }
-/*******************************************************************************/
