@@ -101,6 +101,11 @@ GtkWidget* create_units_tab(GtkWidget *window);
 GtkWidget* create_update_tab(GtkWidget *window);
 GtkWidget* create_test_tab(GtkWidget *window);
 void font_changed_handler(GtkFontButton *widget, gpointer user_data);
+gboolean process_visuals_tab(GtkWidget *vbox);
+gboolean process_display_tab(GtkWidget *vbox);
+gboolean process_units_tab(GtkWidget *vbox);
+gboolean process_update_tab(GtkWidget *vbox);
+gboolean process_sensor_tab(GtkWidget *vbox);
 /*******************************************************************************/
 extern void redraw_home_window(gboolean first_start);
 extern void remove_periodic_event(void);
