@@ -104,13 +104,21 @@ c2f(float temp){
     return (temp * 1.8f ) + 32.0f;
 }
 /*******************************************************************************/
-/* convert preesure */
+/* convert pressure */
 float
 mb2inch(float pressure){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    return ( pressure / 1000.0f / 100000.0f * 3386.389f );
+    return ( pressure / 1000.0f * 100000.0f / ( 3.386389f * 1000.0f ));
+}
+/*******************************************************************************/
+float
+mb2mm(float pressure){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    return ( pressure / 1000.0f * 100000.0f *  7.5006f * 0.001f );
 }
 /*******************************************************************************/
 void
